==> opennms-model-26.0.0-20190914.214320-12-sources.jar: org/opennms/netmgt/model/OnmsMetaDataList.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2019 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2019 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.model;

import java.util.Collection;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.codehaus.jackson.annotate.JsonProperty;
import org.codehaus.jackson.map.annotate.JsonRootName;
import org.opennms.core.config.api.JaxbListWrapper;

@XmlRootElement(name = "meta-data-list")
@XmlAccessorType(XmlAccessType.NONE)
@JsonRootName("meta-data-list")
public class OnmsMetaDataList extends JaxbListWrapper<OnmsMetaData> {
    private static final long serialVersionUID = 1L;

    public OnmsMetaDataList() { super(); }
    public OnmsMetaDataList(final Collection<? extends OnmsMetaData> onmsNodeMetaData) {
        super(onmsNodeMetaData);
    }

    @XmlElement(name="meta-data")
    @JsonProperty(" meta-data")
    public List<OnmsMetaData> getObjects() {
        return super.getObjects();
    }

    public List<OnmsMetaData> getMetaDataList() {
        return getObjects();
    }
}

==> opennms-model-26.0.0-20190927.231042-20-sources.jar: org/opennms/netmgt/model/OnmsMetaDataList.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2019 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2019 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.model;

import java.util.Collection;
import java.util.List;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.codehaus.jackson.annotate.JsonProperty;
import org.codehaus.jackson.map.annotate.JsonRootName;
import org.opennms.core.config.api.JaxbListWrapper;

@XmlRootElement(name = "meta-data-list")
@JsonRootName("metaDataList")
public class OnmsMetaDataList extends JaxbListWrapper<OnmsMetaData> {
    private static final long serialVersionUID = 1L;

    public OnmsMetaDataList() { super(); }
    public OnmsMetaDataList(final Collection<? extends OnmsMetaData> onmsNodeMetaData) {
        super(onmsNodeMetaData);
    }

    @XmlElement(name="meta-data")
    @JsonProperty("metaData")
    public List<OnmsMetaData> getObjects() {
        return super.getObjects();
    }
}
